tiled.queries.Contains
======================

.. currentmodule:: tiled.queries

.. autoclass:: Contains

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Contains.__init__
      ~Contains.decode
      ~Contains.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Contains.key
      ~Contains.value
   
   